#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from onf_website.shared.view.skin.interfaces import IONFViewItemsPortletNewsRendererSettings
from onf_website.skin.public.layer import IONFBaseLayer
from pyams_content.shared.view.portlet.interfaces import IViewItemsPortletSettings
from pyams_portal.interfaces import IPortalContext, IPortletRenderer
from pyams_skin.layer import IPyAMSLayer

# import packages
from onf_website.skin.public import owl_carousel_init, owl_navigation
from persistent import Persistent
from pyams_portal.portlet import PortletRenderer
from pyams_sequence.reference import get_reference_target
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config
from pyams_utils.factory import factory_config
from zope.interface import implementer, Interface
from zope.container.contained import Contained
from zope.schema.fieldproperty import FieldProperty

from onf_website import _


@factory_config(provided=IONFViewItemsPortletNewsRendererSettings)
@implementer(IONFViewItemsPortletNewsRendererSettings)
class ONFViewItemsPortletNewsRendererSettings(Persistent, Contained):
    """View items portlet renderer settings"""

    list_reference = FieldProperty(IONFViewItemsPortletNewsRendererSettings['list_reference'])
    link_label = FieldProperty(IONFViewItemsPortletNewsRendererSettings['link_label'])

    def get_target(self):
        if self.list_reference is not None:
            return get_reference_target(self.list_reference)


@adapter_config(name='ONF::view.actus',
                context=(IPortalContext, IPyAMSLayer, Interface, IViewItemsPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/actus-render.pt', layer=IONFBaseLayer)
class ONFViewItemsPortletNewsRenderer(PortletRenderer):
    """View items portlet renderer"""

    label = _("ONF: news and folders")

    settings_interface = IONFViewItemsPortletNewsRendererSettings
    resources = (owl_carousel_init, owl_navigation)
